==> hx_components_flutter-1.0.0.tar.gz: lib/src/widgets/hx_checkbox.dart <==
import 'package:flutter/material.dart';

import 'package:hx_components_flutter/src/shared/app_colors.dart';

import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxCheckbox extends StatefulWidget {
  bool? value;
  final String label;
  Color borderColor;
  Color backgroundColor;
  Color checkboxBackgroundColor;
  Color textColor;
  Function? onTap;

  HxCheckbox.light({
    required this.value,
    required this.label,
    this.onTap,
  })  : borderColor = kcGrey,
        checkboxBackgroundColor = kcBackgroundColor,
        backgroundColor = kcLightGrey,
        textColor = kcMainText;

  HxCheckbox.dark({
    required this.value,
    required this.label,
    this.onTap,
  })  : borderColor = kcLightGrey,
        checkboxBackgroundColor = kcMainText,
        backgroundColor = kcDarkThemeGrey,
        textColor = kcBackgroundColor;

  @override
  State<HxCheckbox> createState() => _HxCheckboxState();
}

class _HxCheckboxState extends State<HxCheckbox> {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          color: widget.backgroundColor,
        ),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 10.0),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                height: 17.5,
                width: 17.5,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(5.0),
                  color: widget.checkboxBackgroundColor,
                ),
                child: Checkbox(
                  checkColor: kcBackgroundColor,
                  side: BorderSide(color: widget.borderColor),
                  fillColor: MaterialStateProperty.all<Color>(kcPrimaryColor),
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(5.0)),
                  value: widget.value,
                  onChanged: (bool? value) {
                    setState(() {
                      widget.value = value;
                    });
                  },
                ),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 4.0),
                child: HxText.body(widget.label, color: widget.textColor),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> hx_components_flutter-1.0.7.tar.gz: lib/src/widgets/hx_checkbox.dart <==
import 'package:flutter/material.dart';

import 'package:hx_components_flutter/src/shared/app_colors.dart';

import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxCheckbox extends StatefulWidget {
  bool? value;
  final String label;
  Color borderColor;
  Color backgroundColor;
  Color checkboxBackgroundColor;
  Color textColor;
  Function? onTap;

  HxCheckbox.light({
    required this.value,
    required this.label,
    this.onTap,
  })  : borderColor = kcGrey,
        checkboxBackgroundColor = kcBackgroundColor,
        backgroundColor = kcLightGrey,
        textColor = kcMainText;

  HxCheckbox.dark({
    required this.value,
    required this.label,
    this.onTap,
  })  : borderColor = kcLightGrey,
        checkboxBackgroundColor = kcMainText,
        backgroundColor = kcDarkThemeGrey,
        textColor = kcBackgroundColor;

  @override
  State<HxCheckbox> createState() => _HxCheckboxState();
}

class _HxCheckboxState extends State<HxCheckbox> {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          color: widget.backgroundColor,
        ),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 10.0),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                height: 17.5,
                width: 17.5,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(5.0),
                  color: widget.checkboxBackgroundColor,
                ),
                child: Checkbox(
                  checkColor: kcBackgroundColor,
                  side: BorderSide(color: widget.borderColor),
                  fillColor: MaterialStateProperty.all<Color>(kcPrimaryColor),
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(5.0)),
                  value: widget.value,
                  onChanged: (bool? value) {
                    setState(() {
                      widget.value = value;
                    });
                  },
                ),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 4.0),
                child: HxText(widget.label, color: widget.textColor),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
